Learn R Programming

beezdemand (version 0.2.0)

.hurdle_transform_random_effects: Transform Random Effects to Original Scale

Description

Internal function to transform standardized random effects (u) to the original scale using the Cholesky decomposition of the covariance matrix.

Usage

.hurdle_transform_random_effects(u_hat, coefficients, n_re)

Value

Matrix of random effects on original scale with named columns.

Arguments

u_hat

Matrix of standardized random effects.

coefficients

Named vector of fixed effect coefficients.

n_re

Number of random effects.