| GetDescriptives | R Documentation |
Calculates descriptive statistics from purchase task data.
GetDescriptives(
dat,
bwplot = FALSE,
outdir = "../plots/",
device = "png",
filename = "bwplot"
)
dat |
Dataframe (long form) |
bwplot |
Boolean. If TRUE, a ggplot2 box and whisker plot is saved. Default is FALSE. |
outdir |
Character. Directory where plot will be saved. Be sure to include trailing '/'. Default location is one level up in "../plots/". |
device |
Character. Type of file. Default is "png". Can be "pdf". |
filename |
Character. Specify filename. Defualt is "bwplot". |
GetDescriptives() has been superseded by get_descriptive_summary(), which
provides a modern S3 interface with standardized methods (print(), summary(), plot()).
GetDescriptives() will continue to work but is no longer recommended for new code.
Provides the following descriptive statistics from purchase task data at each price: mean consumption, median consumption, standard deviation of consumption, proportion of 0 values, number of NAs, minimum consumption, and maximum consumption.
Dataframe with descriptive statistics
Brent Kaplan bkaplan.ku@gmail.com
get_descriptive_summary() for the modern interface
GetDescriptives(apt)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.