GetEmpirical: GetEmpirical

View source: R/analyze.R

GetEmpiricalR Documentation

GetEmpirical

Description

Calculates empirical measures for purchase task data

Usage

GetEmpirical(dat, xcol = "x", ycol = "y", idcol = "id")

Arguments

dat

data frame (long form) of purchase task data.

xcol

The column name that should be treated as "x" data

ycol

The column name that should be treated as "y" data

idcol

The column name that should be treated as dataset identifier

Details

[Superseded]

GetEmpirical() has been superseded by get_empirical_measures(), which provides a modern S3 interface with standardized methods (print(), summary(), plot()). GetEmpirical() will continue to work but is no longer recommended for new code.

Will calculate and return the following empirical measures: Intensity, BP0, BP1, Omax, and Pmax

Value

Data frame of empirical measures

Author(s)

Brent Kaplan bkaplan.ku@gmail.com

See Also

get_empirical_measures() for the modern interface

Examples

## Obtain empirical measures
GetEmpirical(apt)

beezdemand documentation built on March 3, 2026, 9:07 a.m.