GetK: Get K

View source: R/analyze.R

GetKR Documentation

Get K

Description

Calculates a k value by looking for the max/min consumption across entire dataset and adds .5 to that range

Usage

GetK(dat, mnrange = TRUE)

Arguments

dat

Dataframe (long form)

mnrange

Boolean for whether k should be calculated based on the mean range + .5

Details

[Superseded]

GetK() has been superseded by get_k(), which provides explicit parameters for the adjustment value and optional verbose output for better transparency. GetK() will continue to work but is no longer recommended for new code.

Will look for maximum/minimum greater zero

Value

Numeric

Author(s)

Brent Kaplan bkaplan.ku@gmail.com

See Also

get_k() for the modern interface

Examples

GetK(apt)

beezdemand documentation built on March 3, 2026, 9:07 a.m.