apt: Example alcohol purchase task data

aptR Documentation

Example alcohol purchase task data

Description

A dataset containing alcohol purchase task data for a small number of participants

Usage

apt

Format

Long-form data.frame with columns: id, x, y. Participants were asked how many standard sized alcoholic beverages they would buy at various prices.


beezdemand documentation built on March 3, 2026, 9:07 a.m.