| beezdemand-package | R Documentation |
Facilitates many of the analyses performed in studies of behavioral economic demand. The package supports commonly-used options for modeling operant demand including (1) data screening proposed by Stein, Koffarnus, Snider, Quisenberry, & Bickel (2015; \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1037/pha0000020")}), (2) fitting models of demand such as linear (Hursh, Raslear, Bauman, & Black, 1989, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/978-94-009-2470-3_22")}), exponential (Hursh & Silberberg, 2008, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1037/0033-295X.115.1.186")}) and modified exponential (Koffarnus, Franck, Stein, & Bickel, 2015, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1037/pha0000045")}), and (3) calculating numerous measures relevant to applied behavioral economists (Intensity, Pmax, Omax). Also supports plotting and comparing data.
Maintainer: Brent Kaplan bkaplan.ku@gmail.com (ORCID) [copyright holder]
Other contributors:
Shawn Gilroy shawn.gilroy@temple.edu [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.