dot-calc_observed_pmax_omax: Calculate Observed Pmax and Omax for a Single Subject

.calc_observed_pmax_omaxR Documentation

Calculate Observed Pmax and Omax for a Single Subject

Description

Calculate Observed Pmax and Omax for a Single Subject

Usage

.calc_observed_pmax_omax(price, consumption)

Arguments

price

Numeric vector of prices

consumption

Numeric vector of consumption values

Value

List with observed metrics


beezdemand documentation built on March 3, 2026, 9:07 a.m.