Formats a canonical parameter name with the appropriate scale prefix.
Usage
format_param_name(param, scale = c("natural", "log", "log10"))Formats a canonical parameter name with the appropriate scale prefix.
format_param_name(param, scale = c("natural", "log", "log10"))