View source: R/param-registry.R
| get_canonical_param | R Documentation |
Maps legacy or variant parameter names to canonical names.
get_canonical_param(name)
name |
Character. Input parameter name. |
Character. Canonical parameter name or original if no mapping found.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.