| get_hurdle_param_summary | R Documentation |
Provides summary statistics for subject-level demand parameters from a hurdle demand model. This is analogous to EMMs but based on empirical Bayes estimates of subject-specific parameters.
get_hurdle_param_summary(fit_obj, ci_level = 0.95)
fit_obj |
A |
ci_level |
Confidence level for intervals (default 0.95). |
A data frame with summary statistics for each parameter:
Parameter name
Mean across subjects
Standard deviation across subjects
Median across subjects
Lower confidence limit (based on percentiles)
Upper confidence limit (based on percentiles)
Minimum value
Maximum value
fit_demand_hurdle, get_subject_pars
data(apt)
fit <- fit_demand_hurdle(apt, y_var = "y", x_var = "x", id_var = "id")
get_hurdle_param_summary(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.