View source: R/mixed-methods.R
| get_observed_demand_param_emms | R Documentation |
This function is a wrapper around get_demand_param_emms. It first calls
get_demand_param_emms to calculate Estimated Marginal Means (EMMs) for
Q0 and alpha parameters over all combinations of the specified factor levels.
It then filters these results to return EMMs only for the combinations of
factor levels that were actually present in the original dataset used to
fit the beezdemand_nlme model.
get_observed_demand_param_emms(
fit_obj,
factors_in_emm = NULL,
at = NULL,
ci_level = 0.95,
include_ev = FALSE,
...
)
fit_obj |
A |
factors_in_emm |
Character vector of factor names to compute EMMs over.
Defaults to all factors present in the |
at |
Optional named list specifying levels of conditioning variables for |
ci_level |
Confidence level for the EMMs (default 0.95).
Passed to |
include_ev |
Logical. If TRUE, calculates and includes Essential Value (EV)
derived from alpha. Passed to |
... |
Additional arguments passed to |
A tibble similar to the output of get_demand_param_emms, but filtered
to include only rows corresponding to factor level combinations that were
observed in the original fit_obj$data. Contains:
Factor levels |
Columns for each factor in |
Q0_param_log10, alpha_param_log10 |
EMMs for model parameters (log10 scale) and CIs. |
Q0_natural, alpha_natural |
EMMs back-transformed to natural scale and CIs. |
EV, LCL_EV, UCL_EV |
(If |
get_demand_param_emms
data(ko, package = "beezdemand")
ko$y_ll4 <- ll4(ko$y, lambda = 4)
fit <- fit_demand_mixed(ko, y_var = "y_ll4", x_var = "x",
id_var = "monkey", factors = "dose", equation_form = "zben")
get_observed_demand_param_emms(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.