View source: R/fixed-methods.R
| predict.beezdemand_fixed | R Documentation |
Predict Method for beezdemand_fixed
## S3 method for class 'beezdemand_fixed'
predict(
object,
newdata = NULL,
type = c("response", "link"),
se.fit = FALSE,
interval = c("none", "confidence"),
level = 0.95,
...
)
object |
A |
newdata |
A data frame containing a price column matching the fitted
object's |
type |
One of |
se.fit |
Logical; if |
interval |
One of |
level |
Confidence level when |
... |
Unused. |
A tibble containing the original newdata columns, plus .fitted
and, when requested, .se.fit and .lower/.upper. If newdata does not
include an id column, predictions are returned for all subjects (cross
product of newdata × subjects) unless k is subject-specific (k = "ind").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.