ranef.beezdemand_nlme: Extract Random Effects from a beezdemand_nlme Model

View source: R/mixed-methods.R

ranef.beezdemand_nlmeR Documentation

Extract Random Effects from a beezdemand_nlme Model

Description

S3 method for ranef for objects of class beezdemand_nlme. Extracts the random effects from the fitted nlme model.

Usage

## S3 method for class 'beezdemand_nlme'
ranef(object, ...)

Arguments

object

A beezdemand_nlme object.

...

Additional arguments passed to nlme::ranef().

Value

A data frame (or list of data frames if multiple levels of grouping) of random effects, as returned by ranef.nlme().

See Also

coef.beezdemand_nlme, fixef.beezdemand_nlme


beezdemand documentation built on March 3, 2026, 9:07 a.m.