View source: R/systematic-methods.R
| summary.cp_unsystematic | R Documentation |
Summarizes systematic and unsystematic patterns from multiple calls to
check_unsystematic_cp(). This includes overall proportions, trend and bounce
direction counts, and optionally summaries by subject or group.
## S3 method for class 'cp_unsystematic'
summary(object, ...)
object |
A data frame containing results from multiple |
... |
Additional arguments (currently unused) |
A list of class summary.cp_unsystematic with the following elements:
Number of total patterns examined.
Count of systematic patterns (no bounce).
Count of unsystematic patterns (bounce detected).
Proportion of systematic patterns.
Proportion of unsystematic patterns.
Breakdown of trend directions.
Breakdown of bounce directions.
(Optional) Summary of zero-reversal patterns, if present in input.
(Optional) Summary of zero-return patterns, if present in input.
(Optional) Summary stats by 'group'.
(Optional) Top IDs with unsystematic patterns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.