Internal function to transform standardized random effects (u) to the original scale using the Cholesky decomposition of the covariance matrix.
.hurdle_transform_random_effects(u_hat, coefficients, n_re)Matrix of random effects on original scale with named columns.
Matrix of standardized random effects.
Named vector of fixed effect coefficients.
Number of random effects.