Calculates descriptive statistics from purchase task data.
GetDescriptives(
dat,
bwplot = FALSE,
outdir = "../plots/",
device = "png",
filename = "bwplot"
)Dataframe with descriptive statistics
Dataframe (long form)
Boolean. If TRUE, a ggplot2 box and whisker plot is saved. Default is FALSE.
Character. Directory where plot will be saved. Be sure to include trailing '/'. Default location is one level up in "../plots/".
Character. Type of file. Default is "png". Can be "pdf".
Character. Specify filename. Defualt is "bwplot".
Brent Kaplan bkaplan.ku@gmail.com
GetDescriptives() has been superseded by get_descriptive_summary(), which
provides a modern S3 interface with standardized methods (print(), summary(), plot()).
GetDescriptives() will continue to work but is no longer recommended for new code.
Provides the following descriptive statistics from purchase task data at each price: mean consumption, median consumption, standard deviation of consumption, proportion of 0 values, number of NAs, minimum consumption, and maximum consumption.
get_descriptive_summary() for the modern interface