| GetEmpirical | R Documentation |
Calculates empirical measures for purchase task data
GetEmpirical(dat, xcol = "x", ycol = "y", idcol = "id")
dat |
data frame (long form) of purchase task data. |
xcol |
The column name that should be treated as "x" data |
ycol |
The column name that should be treated as "y" data |
idcol |
The column name that should be treated as dataset identifier |
GetEmpirical() has been superseded by get_empirical_measures(), which
provides a modern S3 interface with standardized methods (print(), summary(), plot()).
GetEmpirical() will continue to work but is no longer recommended for new code.
Will calculate and return the following empirical measures: Intensity, BP0, BP1, Omax, and Pmax
Data frame of empirical measures
Brent Kaplan bkaplan.ku@gmail.com
get_empirical_measures() for the modern interface
## Obtain empirical measures
GetEmpirical(apt)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.