Learn R Programming

beezdemand (version 0.2.0)

GetEmpirical: GetEmpirical

Description

Calculates empirical measures for purchase task data

Usage

GetEmpirical(dat, xcol = "x", ycol = "y", idcol = "id")

Value

Data frame of empirical measures

Arguments

dat

data frame (long form) of purchase task data.

xcol

The column name that should be treated as "x" data

ycol

The column name that should be treated as "y" data

idcol

The column name that should be treated as dataset identifier

Author

Brent Kaplan bkaplan.ku@gmail.com

Details

[Superseded]

GetEmpirical() has been superseded by get_empirical_measures(), which provides a modern S3 interface with standardized methods (print(), summary(), plot()). GetEmpirical() will continue to work but is no longer recommended for new code.

Will calculate and return the following empirical measures: Intensity, BP0, BP1, Omax, and Pmax

See Also

get_empirical_measures() for the modern interface

Examples

Run this code
## Obtain empirical measures
GetEmpirical(apt)

Run the code above in your browser using DataLab