| GetK | R Documentation |
Calculates a k value by looking for the max/min consumption across entire dataset and adds .5 to that range
GetK(dat, mnrange = TRUE)
dat |
Dataframe (long form) |
mnrange |
Boolean for whether k should be calculated based on the mean range + .5 |
GetK() has been superseded by get_k(), which provides explicit parameters
for the adjustment value and optional verbose output for better transparency.
GetK() will continue to work but is no longer recommended for new code.
Will look for maximum/minimum greater zero
Numeric
Brent Kaplan bkaplan.ku@gmail.com
get_k() for the modern interface
GetK(apt)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.