Learn R Programming

beezdemand (version 0.2.0)

GetK: Get K

Description

Calculates a k value by looking for the max/min consumption across entire dataset and adds .5 to that range

Usage

GetK(dat, mnrange = TRUE)

Value

Numeric

Arguments

dat

Dataframe (long form)

mnrange

Boolean for whether k should be calculated based on the mean range + .5

Author

Brent Kaplan bkaplan.ku@gmail.com

Details

[Superseded]

GetK() has been superseded by get_k(), which provides explicit parameters for the adjustment value and optional verbose output for better transparency. GetK() will continue to work but is no longer recommended for new code.

Will look for maximum/minimum greater zero

See Also

get_k() for the modern interface

Examples

Run this code
GetK(apt)

Run the code above in your browser using DataLab