R/data.R
apt.Rd
A dataset containing alcohol purchase task data for a small number of participants
apt
Long-form data.frame with columns: id, x, y. Participants were asked how many standard sized alcoholic beverages they would buy at various prices.