| apt_full | R Documentation |
A larger dataset containing alcohol purchase task data with demographic covariates. Suitable for testing hurdle models and mixed-effects models with covariates.
apt_full
A data frame with 18,700 rows and 8 columns:
Unique participant identifier (1-1100)
Participant gender (Male/Female)
Participant age in years
Number of binge drinking episodes
Total number of drinks consumed
Total hours spent drinking
Price point for the purchase task
Number of drinks participant would purchase at price x
data(apt_full)
# Use a subset for quick demonstration
apt_sub <- apt_full[apt_full$id %in% unique(apt_full$id)[1:20], ]
fit <- fit_demand_hurdle(apt_sub, y_var = "y", x_var = "x", id_var = "id")
summary(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.