View source: R/mixed-methods.R
| coef.beezdemand_nlme | R Documentation |
Provides methods to extract fixed effects, random effects, or subject-specific
(combined fixed + random) coefficients from a beezdemand_nlme object.
This is an S3 method for the generic coef function.
## S3 method for class 'beezdemand_nlme'
coef(
object,
type = "combined",
report_space = c("internal", "natural", "log10"),
...
)
object |
A |
type |
Character, type of coefficients to extract. One of:
|
report_space |
Character. One of |
... |
Additional arguments passed to the underlying |
Depending on type:
type="fixed": A named numeric vector of fixed-effect coefficients.
type="random": A data frame (or list of data frames if multiple levels of grouping)
of random effects, as returned by ranef.nlme().
type="combined": A data frame where rows are subjects (from id_var)
and columns are the Q0 and alpha parameters, representing subject-specific
estimates (on the log10 scale).
fixef.beezdemand_nlme, ranef.beezdemand_nlme
data(ko)
fit <- fit_demand_mixed(ko, y_var = "y_ll4", x_var = "x",
id_var = "monkey", equation_form = "zben")
coef(fit, type = "fixed")
coef(fit, type = "random")
coef(fit, type = "combined")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.