| cp_posthoc_slopes | R Documentation |
This function performs pairwise comparisons of slopes between groups in a cross-price demand model, but only when a significant interaction is present. The emmeans table showing estimated marginal means for slopes is always returned.
cp_posthoc_slopes(object, alpha = 0.05, adjust = "tukey", ...)
object |
A cp_model_lmer object from fit_cp_linear |
alpha |
Significance level for testing (default: 0.05) |
adjust |
Method for p-value adjustment; see emmeans::contrast (default: "tukey") |
... |
Additional arguments passed to emmeans |
List containing the emmeans table and optionally pairwise comparisons if interaction is significant
data(etm)
fit <- fit_cp_linear(etm, type = "mixed", group_effects = TRUE)
cp_posthoc_slopes(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.