| .hurdle_get_param_names | R Documentation |
Internal function to get the names of fixed effect parameters and variance component names based on model configuration.
.hurdle_get_param_names(n_re, has_k)
n_re |
Number of random effects (2 or 3). |
has_k |
Logical, whether the model has a k parameter. |
A list with fixed_names, var_names, and rho_names.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.