| .hurdle_transform_random_effects | R Documentation |
Internal function to transform standardized random effects (u) to the original scale using the Cholesky decomposition of the covariance matrix.
.hurdle_transform_random_effects(u_hat, coefficients, n_re)
u_hat |
Matrix of standardized random effects. |
coefficients |
Named vector of fixed effect coefficients. |
n_re |
Number of random effects. |
Matrix of random effects on original scale with named columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.