View source: R/mixed-methods.R
| get_demand_comparisons | R Documentation |
Conducts pairwise comparisons for Q0 and/or alpha parameters from a
beezdemand_nlme model across levels of specified factors.
Comparisons are performed on the log10 scale of the parameters.
Results include estimates of differences (on log10 scale) and
optionally, ratios (on the natural scale by applying 10^difference).
get_demand_comparisons(
fit_obj,
params_to_compare = c("Q0", "alpha"),
compare_specs = NULL,
contrast_type = "pairwise",
contrast_by = NULL,
adjust = "tukey",
at = NULL,
ci_level = 0.95,
report_ratios = TRUE,
...
)
fit_obj |
A |
params_to_compare |
Character vector: "Q0", "alpha", or |
compare_specs |
A formula specifying the factors whose levels are to be included in the EMM calculation
prior to contrasting. This defines the "cells" of your design for EMMs.
E.g., |
contrast_type |
Character string specifying the type of contrast (passed to |
contrast_by |
Optional character vector of factor names to condition the contrasts by (passed to |
adjust |
P-value adjustment method. Default "tukey". |
at |
Optional named list for |
ci_level |
Confidence level. Default 0.95. |
report_ratios |
Logical. If TRUE, reports contrasts as ratios. Default |
... |
Additional arguments passed to |
A list named by parameter. Each element contains:
emmeans |
Tibble of EMMs (log10 scale) with CIs. |
contrasts_log10 |
Tibble of comparisons (log10 differences) with CIs and p-values. |
contrasts_ratio |
(If |
S3 class beezdemand_comparison is assigned.
data(ko, package = "beezdemand")
ko$y_ll4 <- ll4(ko$y, lambda = 4)
fit <- fit_demand_mixed(ko, y_var = "y_ll4", x_var = "x",
id_var = "monkey", factors = "dose", equation_form = "zben")
get_demand_comparisons(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.