Learn R Programming

beezdemand (version 0.2.0)

glance.cp_model_nls: Get model summaries from a cross-price model

Description

This function extracts model summary statistics from a cross-price demand model into a single-row data frame, following the conventions of the broom package. It returns goodness-of-fit measures and other model information.

Usage

# S3 method for cp_model_nls
glance(x, ...)

Value

A one-row data frame with model summary statistics:

r.squared

R-squared value indicating model fit

aic

Akaike Information Criterion

bic

Bayesian Information Criterion

equation

The equation type used in the model

method

The method used to fit the model

transform

The transformation applied to the data, if any

Arguments

x

A model object from fit_cp_nls or fit_cp_linear

...

Additional arguments (unused)

Examples

Run this code
# \donttest{
data(etm)
fit <- fit_cp_nls(etm, equation = "exponentiated")
glance(fit)
# }

Run the code above in your browser using DataLab