Creates diagnostic plots for model residuals including residuals vs fitted, scale-location, and histogram of residuals.
Usage
plot_residuals(object, type = c("all", "fitted", "histogram", "qq"), ...)Examples
# \donttest{
data(apt)
fit <- fit_demand_hurdle(apt, y_var = "y", x_var = "x", id_var = "id")
#> Sample size may be too small for reliable estimation.
#> Subjects: 10, Parameters: 12, Recommended minimum: 60 subjects.
#> Consider using more subjects or the simpler 2-RE model.
#> Fitting HurdleDemand3RE model...
#> Part II: zhao_exponential
#> Subjects: 10, Observations: 160
#> Fixed parameters: 12, Random effects per subject: 3
#> Optimizing...
#> Converged in 81 iterations
#> Computing standard errors...
#> Done. Log-likelihood: 32.81
plot_residuals(fit)
#> $fitted
#> `geom_smooth()` using formula = 'y ~ x'
#>
#> $histogram
#>
#> $qq
#>
#> attr(,"class")
#> [1] "beezdemand_diagnostic_plots" "list"
# }