Learn R Programming

beezdemand (version 0.2.0)

print.beezdemand_nlme: Print Method for beezdemand_nlme Objects

Description

Provides a concise summary of a beezdemand_nlme object, typically displaying the call, model specifications, and key results from the nlme fit if successful.

Usage

# S3 method for beezdemand_nlme
print(x, digits = max(3L, getOption("digits") - 3L), ...)

Value

Invisibly returns the original object x.

Arguments

x

An object of class beezdemand_nlme.

digits

Minimal number of significant digits, see print.default.

...

Additional arguments passed to print.nlme if the model exists.

Examples

Run this code
# \donttest{
data(ko)
fit <- fit_demand_mixed(ko, y_var = "y_ll4", x_var = "x",
                        id_var = "monkey", equation_form = "zben")
print(fit)
# }

Run the code above in your browser using DataLab