powered by
Provides a concise summary of a beezdemand_nlme object, typically displaying the call, model specifications, and key results from the nlme fit if successful.
beezdemand_nlme
nlme
# S3 method for beezdemand_nlme print(x, digits = max(3L, getOption("digits") - 3L), ...)
Invisibly returns the original object x.
x
An object of class beezdemand_nlme.
Minimal number of significant digits, see print.default.
print.default
Additional arguments passed to print.nlme if the model exists.
print.nlme
# \donttest{ data(ko) fit <- fit_demand_mixed(ko, y_var = "y_ll4", x_var = "x", id_var = "monkey", equation_form = "zben") print(fit) # }
Run the code above in your browser using DataLab