Skip to contents

S3 method for ranef for objects of class beezdemand_nlme. Extracts the random effects from the fitted nlme model.

Usage

# S3 method for class 'beezdemand_nlme'
ranef(object, ...)

Arguments

object

A beezdemand_nlme object.

...

Additional arguments passed to nlme::ranef().

Value

A data frame (or list of data frames if multiple levels of grouping) of random effects, as returned by ranef.nlme().