Extract Random Effects from a beezdemand_nlme Model
Source:R/mixed-methods.R
ranef.beezdemand_nlme.RdS3 method for ranef for objects of class beezdemand_nlme.
Extracts the random effects from the fitted nlme model.
Arguments
- object
A
beezdemand_nlmeobject.- ...
Additional arguments passed to
nlme::ranef().
Value
A data frame (or list of data frames if multiple levels of grouping)
of random effects, as returned by ranef.nlme().