View source: R/mixed-methods.R
| ranef.beezdemand_nlme | R Documentation |
S3 method for ranef for objects of class beezdemand_nlme.
Extracts the random effects from the fitted nlme model.
## S3 method for class 'beezdemand_nlme'
ranef(object, ...)
object |
A |
... |
Additional arguments passed to |
A data frame (or list of data frames if multiple levels of grouping)
of random effects, as returned by ranef.nlme().
coef.beezdemand_nlme, fixef.beezdemand_nlme
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.