Learn R Programming

beezdemand (version 0.2.0)

ranef.beezdemand_nlme: Extract Random Effects from a beezdemand_nlme Model

Description

S3 method for ranef for objects of class beezdemand_nlme. Extracts the random effects from the fitted nlme model.

Usage

# S3 method for beezdemand_nlme
ranef(object, ...)

Value

A data frame (or list of data frames if multiple levels of grouping) of random effects, as returned by ranef.nlme().

Arguments

object

A beezdemand_nlme object.

...

Additional arguments passed to nlme::ranef().

See Also

coef.beezdemand_nlme, fixef.beezdemand_nlme