| validate_demand_data | R Documentation |
Internal helper function to validate required columns in demand data and ensure that specified factor columns are correctly formatted and have unused levels dropped.
validate_demand_data(data, y_var, x_var, id_var, factors = NULL)
data |
A data frame. |
y_var |
Character string, the name of the dependent variable column. |
x_var |
Character string, the name of the independent variable column. |
id_var |
Character string, the name of the subject/group identifier column. |
factors |
Character vector of factor names (can be NULL). |
The validated and prepared data frame.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.